@@ -8,7 +8,7 @@
 #'  
 #' Kendall's W values range between 0 (no agreement) to 1 (full agreement)
 #' 
-#' @author David Brown, Kauê de Sousa and Jacob van Etten
+#' @author David Brown and Jacob van Etten
 #' @family goodness-of-fit functions
 #' @param x an object of class \code{pltree}
 #' @param y an object of class \code{pltree}
@@ -18,7 +18,7 @@
 #' @details 
 #' @importFrom DescTools KendallW
 #' @export
-kendallW <- function(x, ...) {
+kendallW = function(x, ...) {
   
   UseMethod("kendallW")
   
@@ -26,19 +26,19 @@ kendallW <- function(x, ...) {
 
 #' @rdname kendallW 
 #' @export
-kendallW.default <- function(x, y, ...) {
+kendallW.default = function(x, y, ...) {
   
-  pred_ranks <- x
+  pred_ranks = x
   
-  obs_ranks <- y
+  obs_ranks = y
   
-  kw <- mean(unlist(lapply(X = seq_len(nrow(pred_ranks)),
-                           FUN = function(X){
-                             DescTools::KendallW(data.frame("pred" = pred_ranks[X, ],
-                                                            "obs" = obs_ranks[X, ]),
-                                                 correct = TRUE,
-                                                 test = TRUE)$estimate
-                           })))
+  kw = mean(unlist(lapply(X = seq_len(nrow(pred_ranks)),
+                          FUN = function(X){
+                            DescTools::KendallW(data.frame("pred" = pred_ranks[X, ],
+                                                           "obs" = obs_ranks[X, ]),
+                                                correct = TRUE,
+                                                test = TRUE)$estimate
+                          })))
   
   return(kw)
   
@@ -48,32 +48,32 @@ kendallW.default <- function(x, y, ...) {
 #' @rdname kendallW
 #' @method kendallW pltree
 #' @export
-kendallW.pltree <- function(x, newdata = NULL, ...) {
+kendallW.pltree = function(x, newdata = NULL, ...) {
   
   if(class(x)[1] != "pltree"){
     stop("x is not an object of class pltree")
   }
   
-   obs_ranks <- x[[1]]$data[[1]]
+  obs_ranks = x[[1]]$data[[1]]
+  
+  obs_ranks_mtx = obs_ranks[1:length(obs_ranks), , as.grouped_rankings = FALSE]
   
-   obs_ranks_mtx <- obs_ranks[1:length(obs_ranks), , as.grouped_rankings = FALSE]
-   
   
   if(is.null(newdata)){
     
     
-    pred_ranks <- predict(x, type = "rank")
+    pred_ranks = predict(x, type = "rank")
     
   }
-   
-   if(!is.null(newdata)){
-     
-     
-     pred_ranks <- predict(x, newdata = newdata, type = "rank")
-     
-   }
-   
-   kendallW(pred_ranks, obs_ranks_mtx)
+  
+  if(!is.null(newdata)){
+    
+    
+    pred_ranks = predict(x, newdata = newdata, type = "rank")
+    
+  }
+  
+  kendallW(pred_ranks, obs_ranks_mtx)
   
 }
 
